'use client'

import { CommitDetails, getGitActivity } from '@/serverActions/getGitActivity'
import { useMemo, useState } from 'react'
import { GitCommitCard } from '../git-commit-card'
import { Loader2 } from 'lucide-react'

const GitProfile = () => {
  const [commits, setCommits] = useState<CommitDetails[]>([])

  useMemo(async () => {
    if (commits.length) return

    const commitResponse = await getGitActivity()
    setCommits(commitResponse || [])
  }, [commits, setCommits])

  return (
    <div>
      {!!commits.length ?
        commits.map((c) => {
          const refNameSplitArray = c.commitRefName.split('/')
          const refName = refNameSplitArray[refNameSplitArray.length - 1]

          return (
            <GitCommitCard
              key={c.id + c.repoName}
              image={c.avatarUrl}
              title={c.repoName}
              description={c.commitMessage}
              dates={new Date(c.commitTimestamp).toLocaleString()}
              location={refName}
              repoWebsite={c.repoWebsite}
            />
          )
        })
        :
        <div>
          <span className="block text-center">. . . loading contributions . . .</span>
          <Loader2 className='animate-spin size-14 mx-auto my-12' />
        </div>
      }
    </div>
  )
}

export default GitProfile
