import { Avatar, AvatarFallback, AvatarImage } from '@/components/ui/avatar'
import { Badge } from '@/components/ui/badge'
import Link from 'next/link'

interface Props {
  title: string
  description: string
  dates: string
  location: string
  image?: string
  repoWebsite?: string
  links?: readonly {
    icon: React.ReactNode
    title: string
    href: string
  }[]
}

export function GitCommitCard({
  title,
  description,
  dates,
  location,
  image,
  repoWebsite,
  links,
}: Props) {
  return (
    <div className="border-l border-l-purple-800 dark:border-l-purple-300">
      <li className="relative ml-10 py-4 -top-4 list-none">
        <div className="absolute -left-15 flex items-center justify-center bg-white rounded-full">
          <Avatar className="border size-10 m-auto">
            <AvatarImage src={image} alt={title} className="object-contain" />
            <AvatarFallback>{title[0]}</AvatarFallback>
          </Avatar>
        </div>
        <div className="flex flex-1 flex-col justify-start ">
          {dates && <time className="text-xs text-muted-foreground leading-none">{dates}</time>}
          <div>
            <Link target="_blank" href={repoWebsite || ''} className="font-semibold hover:text-lg hover:underline hover:text-purple-800 dark:hover:text-purple-300 transition-all">
              {title}
            </Link>
            {location && (
              <span className="text-sm italic ml-2 text-purple-800 dark:text-purple-300">
                {`=> ${location}`}
              </span>
            )}
          </div>
          {description && (
            <span className="prose dark:prose-invert text-sm text-muted-foreground mt-2">
              {description}
            </span>
          )}
        </div>
        {links && links.length > 0 && (
          <div className="mt-2 flex flex-row flex-wrap items-start gap-2">
            {links?.map((link, idx) => (
              <Link href={link.href} key={idx}>
                <Badge key={idx} title={link.title} className="flex gap-2">
                  {link.icon}
                  {link.title}
                </Badge>
              </Link>
            ))}
          </div>
        )}
      </li>
    </div>
  )
}
