'use server'

type CommitContent = {
  Commits: [any],
  HeadCommit: {
    Message: string,
    Timestamp: string,
  }
}

export type CommitDetails = {
  id: number,
  repoName: string,
  repoUrl: string,
  repoWebsite: string,
  commitMessage: string,
  commitTimestamp: string,
  commitRefName: string,
  avatarUrl: string,
}

export const getGitActivity = async (): Promise<CommitDetails[]> => {
  const gitActivityResponse = await fetch('https://git.beitzah.net/api/v1/users/ysandler/activities/feeds?only-performed-by=true')
  const gitActivityJson = await gitActivityResponse.json()
  const commits = gitActivityJson
    .filter((a: any) => a.op_type === 'commit_repo' && !!a.content)
    .map((c: any) => {
      const repo = c.repo
      const commitContent = JSON.parse(c.content as string) as CommitContent

      return {
        id: c.id,
        repoName: repo.full_name,
        repoUrl: repo.url,
        repoWebsite: repo.html_url,
        commitMessage: commitContent.HeadCommit.Message,
        commitTimestamp: commitContent.HeadCommit.Timestamp,
        commitRefName: c.ref_name || '',
        avatarUrl: repo.owner.avatar_url,
      }
    })

  return commits
}
